==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkPResampleFilter.java <==
// java wrapper for vtkPResampleFilter object
//

package vtk;
import vtk.*;

public class vtkPResampleFilter extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetController_2(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_2(id0); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetUseInputBounds_4(int id0);
  public void SetUseInputBounds(int id0)
    { SetUseInputBounds_4(id0); }

  private native int GetUseInputBounds_5();
  public int GetUseInputBounds()
    { return GetUseInputBounds_5(); }

  private native void UseInputBoundsOn_6();
  public void UseInputBoundsOn()
    { UseInputBoundsOn_6(); }

  private native void UseInputBoundsOff_7();
  public void UseInputBoundsOff()
    { UseInputBoundsOff_7(); }

  private native void SetCustomSamplingBounds_8(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetCustomSamplingBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetCustomSamplingBounds_8(id0,id1,id2,id3,id4,id5); }

  private native void SetCustomSamplingBounds_9(double id0[]);
  public void SetCustomSamplingBounds(double id0[])
    { SetCustomSamplingBounds_9(id0); }

  private native double[] GetCustomSamplingBounds_10();
  public double[] GetCustomSamplingBounds()
    { return GetCustomSamplingBounds_10(); }

  private native void SetSamplingDimension_11(int id0,int id1,int id2);
  public void SetSamplingDimension(int id0,int id1,int id2)
    { SetSamplingDimension_11(id0,id1,id2); }

  private native void SetSamplingDimension_12(int id0[]);
  public void SetSamplingDimension(int id0[])
    { SetSamplingDimension_12(id0); }

  private native int[]  GetSamplingDimension_13();
  public int[]  GetSamplingDimension()
    { return GetSamplingDimension_13(); }

  public vtkPResampleFilter() { super(); }

  public vtkPResampleFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkPResampleFilter.java <==
// java wrapper for vtkPResampleFilter object
//

package vtk;
import vtk.*;

public class vtkPResampleFilter extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetController_2(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_2(id0); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUseInputBounds_4(int id0);
  public void SetUseInputBounds(int id0)
    { SetUseInputBounds_4(id0); }

  private native int GetUseInputBounds_5();
  public int GetUseInputBounds()
    { return GetUseInputBounds_5(); }

  private native void UseInputBoundsOn_6();
  public void UseInputBoundsOn()
    { UseInputBoundsOn_6(); }

  private native void UseInputBoundsOff_7();
  public void UseInputBoundsOff()
    { UseInputBoundsOff_7(); }

  private native void SetCustomSamplingBounds_8(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetCustomSamplingBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetCustomSamplingBounds_8(id0,id1,id2,id3,id4,id5); }

  private native void SetCustomSamplingBounds_9(double id0[]);
  public void SetCustomSamplingBounds(double id0[])
    { SetCustomSamplingBounds_9(id0); }

  private native double[] GetCustomSamplingBounds_10();
  public double[] GetCustomSamplingBounds()
    { return GetCustomSamplingBounds_10(); }

  private native void SetSamplingDimension_11(int id0,int id1,int id2);
  public void SetSamplingDimension(int id0,int id1,int id2)
    { SetSamplingDimension_11(id0,id1,id2); }

  private native void SetSamplingDimension_12(int id0[]);
  public void SetSamplingDimension(int id0[])
    { SetSamplingDimension_12(id0); }

  private native int[]  GetSamplingDimension_13();
  public int[]  GetSamplingDimension()
    { return GetSamplingDimension_13(); }

  public vtkPResampleFilter() { super(); }

  public vtkPResampleFilter(long id) { super(id); }
  public native long   VTKInit();

}
